@@ -41,8 +41,6 @@ sub __setting_menu_entries {
         { name => '_split_config',  text => "- Settings 'split'",            section => 'split'  },
         { name => '_csv_char',      text => "- Settings 'CSV-a'",            section => 'csv'    },
         { name => '_csv_options',   text => "- Settings 'CSV-b'",            section => 'csv'    },
-        { name => '_file_encoding', text => "- File Encoding",               section => 'insert' },
-        { name => 'history_dirs',   text => "- Dir History",                 section => 'insert' },
     ];
     if ( ! $all ) {
         if ( defined $sf->{i}{gc}{source_type} ) {
@@ -53,7 +51,6 @@ sub __setting_menu_entries {
                 splice @$options, 0, 1;
             }
         }
-        splice @$options, -2, 2;
     }
     return $groups, $options;
 }
@@ -95,8 +92,8 @@ sub get_content {
             if ( $choices->[$idx] eq $hidden ) {
                 require App::DBBrowser::Opt::Set;
                 my $opt_set = App::DBBrowser::Opt::Set->new( $sf->{i}, $sf->{o} );
-                say "Options \"Insert Data\"";
-                $opt_set->set_options( $sf->__setting_menu_entries( 1 ) );
+                my $info = "Parse options:";
+                $opt_set->set_options( $sf->__setting_menu_entries( 1 ), $info );
                 next MENU;
             }
             else {
